@@ -3,6 +3,7 @@ import datetime
 import socket
 import logging
 import construct
+import binascii
 from typing import Any, List, Optional  # noqa: F401
 
 from .protocol import Message
@@ -139,7 +140,7 @@ class Device:
             if self.debug > 1:
                 _LOGGER.debug(m)
             _LOGGER.debug("Discovered %s with ts: %s, token: %s",
-                          self._device_id,
+                          binascii.hexlify(self._device_id).decode(),
                           self._device_ts,
                           codecs.encode(m.checksum, 'hex'))
         else:
@@ -184,7 +185,7 @@ class Device:
                 if addr[0] not in seen_addrs:
                     _LOGGER.info("  IP %s (ID: %s) - token: %s",
                                  addr[0],
-                                 m.header.value.device_id.decode(),
+                                 binascii.hexlify(m.header.value.device_id).decode(),
                                  codecs.encode(m.checksum, 'hex'))
                     seen_addrs.append(addr[0])
             except socket.timeout:
@@ -242,7 +243,6 @@ class Device:
             data, addr = s.recvfrom(1024)
             m = Message.parse(data, token=self.token)
             self._device_ts = m.header.value.ts
-            self._device_id = m.header.value.device_id
             if self.debug > 1:
                 _LOGGER.debug("recv from %s: %s", addr[0], m)
 
